# expyhist_crawler

[![Build Status](https://travis-ci.com/expyhist/expyhist_crawler.svg?token=sBxwzSEx9a7E7hUSCuqh&branch=main)](https://travis-ci.com/expyhist/expyhist_crawler)

- These is simply web crawler which simplify job

- v0.0.4
  > Make code clear
- v0.0.3
  > Add new assertIsInstance for special_rank
- v0.0.2
  > Keep folder name same with repo name
- v0.0.1
  > Initial commit